@@ -8,11 +8,13 @@ This package provides a Cython wrapper around winpty C++ library.
 # yapf: disable
 
 # Local imports
+from .ptyprocess import PtyProcess
 from .winpty_wrapper import PTY
 
 
 # yapf: enable
 
 PTY
-VERSION_INFO = (0, 2, 1)
+PtyProcess
+VERSION_INFO = (0, 4, 1)
 __version__ = '.'.join(map(str, VERSION_INFO))
